{# AUTO-GENERATED BY DJANGO SPELLBOOK - DO NOT EDIT #}
{# Regenerate: python manage.py spellbook_md #}

{% extends '__EXTEND_FROM__' %}
{% load spellbook_tags %}
{% load static %}

{% block spellbook %}
{% spellbook_styles %}
<link rel="stylesheet" href="{% static 'django_spellbook/css_modules/sidebar_left.css' %}">

<div class="sb-bg-background sb-text-text">
<div class="spellbook-container">
    <div class="spellbook-layout">
        <nav class="spellbook-toc">
            {% if is_directory_index %}
                {% directory_metadata %}
            {% else %}
                {% page_metadata %}
            {% endif %}
            {% include "django_spellbook/tocs/sidebar_toc.html" %}
            {% if user.is_staff %}
                {% if is_directory_index %}
                    {% directory_metadata "for_dev" %}
                {% else %}
                    {% page_metadata "for_dev" %}
                {% endif %}
            {% endif %}
        </nav>
        <main class="spellbook-content" style="position: relative;">
            {% page_header %}
            {% block spellbook_md %}{% endblock %}
        </main>
    </div>
</div>
</div>
{% endblock %}
